@@ -33,6 +33,7 @@
 #include "eina_private.h"
 #include "eina_tiler.h"
 #include "eina_error.h"
+#include "eina_lock.h"
 
 /*============================================================================*
 *                                  Local                                     *
@@ -109,6 +110,8 @@ struct _Eina_Tiler
    Eina_Rectangle area;
    EINA_MAGIC
    splitter_t splitter;
+
+   Eina_Bool rounding : 1;
 };
 
 #define EINA_MAGIC_CHECK_TILER(d, ...)                                  \
@@ -997,8 +1000,8 @@ static inline void _splitter_del(Eina_Tiler *t)
 }
 
 static inline void _splitter_tile_size_set(Eina_Tiler *t,
-                                           int w __UNUSED__,
-                                           int h __UNUSED__)
+                                           int w EINA_UNUSED,
+                                           int h EINA_UNUSED)
 {
    /* TODO are w and h used for something? */
    t->splitter.rects = list_zeroed;
@@ -1009,23 +1012,25 @@ static inline Eina_Bool _splitter_rect_add(Eina_Tiler *t, Eina_Rectangle *rect)
    rect_node_t *rn;
 
    //printf("ACCOUNTING[1]: add_redraw: %4d,%4d %3dx%3d\n", x, y, w, h);
-   rect->x >>= 1;
-   rect->y >>= 1;
-   rect->w += 2;
-   rect->w >>= 1;
-   rect->h += 2;
-   rect->h >>= 1;
+   if (t->rounding)
+     {
+        rect->x >>= 1;
+        rect->y >>= 1;
+        rect->w += 2;
+        rect->w >>= 1;
+        rect->h += 2;
+        rect->h >>= 1;
+     }
 
    rn = (rect_node_t *)rect_list_node_pool_get();
    rn->_lst = list_node_zeroed;
    rect_init(&rn->rect, rect->x, rect->y, rect->w, rect->h);
    //printf("ACCOUNTING[2]: add_redraw: %4d,%4d %3dx%3d\n", x, y, w, h);
    //testing on my core2 duo desktop - fuzz of 32 or 48 is best.
-#define FUZZ 32
    rect_list_add_split_fuzzy_and_merge(&t->splitter.rects,
                                        (list_node_t *)rn,
-                                       FUZZ * FUZZ,
-                                       FUZZ * FUZZ);
+                                       t->tile.w * t->tile.h,
+                                       t->tile.w * t->tile.h);
    return EINA_TRUE;
 }
 
@@ -1036,14 +1041,17 @@ static inline void _splitter_rect_del(Eina_Tiler *t, Eina_Rectangle *rect)
    if (!t->splitter.rects.head)
       return;
 
-   rect->x += 1;
-   rect->y += 1;
-   rect->x >>= 1;
-   rect->y >>= 1;
-   rect->w -= 1;
-   rect->w >>= 1;
-   rect->h -= 1;
-   rect->h >>= 1;
+   if (t->rounding)
+     {
+        rect->x += 1;
+        rect->y += 1;
+        rect->x >>= 1;
+        rect->y >>= 1;
+        rect->w -= 1;
+        rect->w >>= 1;
+        rect->h -= 1;
+        rect->h >>= 1;
+     }
 
    if ((rect->w <= 0) || (rect->h <= 0))
       return;
@@ -1073,10 +1081,20 @@ static Eina_Bool _iterator_next(Eina_Iterator_Tiler *it, void **data)
 
         cur = ((rect_node_t *)n)->rect;
 
-        it->r.x = cur.left << 1;
-        it->r.y = cur.top << 1;
-        it->r.w = cur.width << 1;
-        it->r.h = cur.height << 1;
+        if (it->tiler->rounding)
+          {
+             it->r.x = cur.left << 1;
+             it->r.y = cur.top << 1;
+             it->r.w = cur.width << 1;
+             it->r.h = cur.height << 1;
+          }
+        else
+          {
+             it->r.x = cur.left;
+             it->r.y = cur.top;
+             it->r.w = cur.width;
+             it->r.h = cur.height;             
+          }
 
         if (eina_rectangle_intersection(&it->r, &it->tiler->area) == EINA_FALSE)
            continue;
@@ -1115,11 +1133,15 @@ EAPI Eina_Tiler *eina_tiler_new(int w, int h)
 {
    Eina_Tiler *t;
 
+   if ((w <= 0) || (h <= 0))
+     return NULL;
+
    t = calloc(1, sizeof(Eina_Tiler));
    t->area.w = w;
    t->area.h = h;
-   t->tile.w = w;
-   t->tile.h = h;
+   t->tile.w = 32;
+   t->tile.h = 32;
+   t->rounding = EINA_TRUE;
    EINA_MAGIC_SET(t, EINA_MAGIC_TILER);
    _splitter_new(t);
    return t;
@@ -1127,6 +1149,9 @@ EAPI Eina_Tiler *eina_tiler_new(int w, int h)
 
 EAPI void eina_tiler_free(Eina_Tiler *t)
 {
+   if (!t)
+     return;
+
    EINA_MAGIC_CHECK_TILER(t);
    _splitter_del(t);
    free(t);
@@ -1138,6 +1163,7 @@ EAPI void eina_tiler_tile_size_set(Eina_Tiler *t, int w, int h)
    if ((w <= 0) || (h <= 0))
       return;
 
+   if (w == 1 || h == 1) t->rounding = EINA_FALSE;
    t->tile.w = w;
    t->tile.h = h;
    _splitter_tile_size_set(t, w, h);
@@ -1148,6 +1174,8 @@ EAPI Eina_Bool eina_tiler_rect_add(Eina_Tiler *t, const Eina_Rectangle *r)
    Eina_Rectangle tmp;
 
    EINA_MAGIC_CHECK_TILER(t, EINA_FALSE);
+   EINA_SAFETY_ON_NULL_RETURN_VAL(r, EINA_FALSE);
+
    if ((r->w <= 0) || (r->h <= 0))
       return EINA_FALSE;
 
@@ -1166,6 +1194,8 @@ EAPI void eina_tiler_rect_del(Eina_Tiler *t, const Eina_Rectangle *r)
    Eina_Rectangle tmp;
 
    EINA_MAGIC_CHECK_TILER(t);
+   EINA_SAFETY_ON_NULL_RETURN(r);
+
    if ((r->w <= 0) || (r->h <= 0))
       return;
 
@@ -1206,7 +1236,7 @@ EAPI Eina_Iterator *eina_tiler_iterator_new(const Eina_Tiler *t)
         sp = (splitter_t *)&(t->splitter);
         to_merge = t->splitter.rects;
         sp->rects = list_zeroed;
-        rect_list_merge_rects(&sp->rects, &to_merge, FUZZ * FUZZ);
+        rect_list_merge_rects(&sp->rects, &to_merge, t->tile.w * t->tile.h);
         sp->need_merge = 0;
      }
 
@@ -1257,6 +1287,10 @@ eina_tile_grid_slicer_iterator_new(int x,
 {
    Eina_Tile_Grid_Slicer_Iterator *it;
 
+   if ((x < 0) || (y < 0) || (w <= 0) || (h <= 0) || 
+       (tile_w <= 0) || (tile_h <= 0))
+     return NULL;
+
    it = calloc(1, sizeof(*it));
    if (!it)
      {
